package com.xinda.iot.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.xinda.iot.mapper.PipMapper;
import com.xinda.iot.domain.Pip;
import com.xinda.iot.service.IPipService;

/**
 * 机构管网Service业务层处理
 * 
 * @author kerwincui
 * @date 2025-04-18
 */
@Service
public class PipServiceImpl implements IPipService 
{
    @Autowired
    private PipMapper pipMapper;

    /**
     * 查询机构管网
     * 
     * @param deptId 机构管网主键
     * @return 机构管网
     */
    @Override
    public Pip selectPipByDeptId(Long deptId)
    {
        return pipMapper.selectPipByDeptId(deptId);
    }

    /**
     * 查询机构管网列表
     * 
     * @param pip 机构管网
     * @return 机构管网
     */
    @Override
    public List<Pip> selectPipList(Pip pip)
    {
        return pipMapper.selectPipList(pip);
    }

    /**
     * 新增机构管网
     * 
     * @param pip 机构管网
     * @return 结果
     */
    @Override
    public int insertPip(Pip pip)
    {
        return pipMapper.insertPip(pip);
    }

    /**
     * 修改机构管网
     * 
     * @param pip 机构管网
     * @return 结果
     */
    @Override
    public int updatePip(Pip pip)
    {
        // 查询指定部门 ID 的 Pip 对象
        Pip result = pipMapper.selectPipByDeptId(pip.getDeptId());
        if (result != null) {
            return   pipMapper.updatePip(pip);
        }else{
            return  pipMapper.insertPip(pip);
        }
    }

    /**
     * 批量删除机构管网
     * 
     * @param deptIds 需要删除的机构管网主键
     * @return 结果
     */
    @Override
    public int deletePipByDeptIds(Long[] deptIds)
    {
        return pipMapper.deletePipByDeptIds(deptIds);
    }

    /**
     * 删除机构管网信息
     * 
     * @param deptId 机构管网主键
     * @return 结果
     */
    @Override
    public int deletePipByDeptId(Long deptId)
    {
        return pipMapper.deletePipByDeptId(deptId);
    }
}
